Trait fixed_math::trig::NormalizeCordic
source · pub trait NormalizeCordic: Sized {
// Required method
fn normalize_cordic(angle_degs: Self) -> (Self, bool);
}Expand description
Get the angle in the range where cordic can run on it also returning if the final result will need to be negated based on where it is on an interval.