Trait fixed_math::traits::SinCos
source · pub trait SinCoswhere
Self: Sized,{
// Required methods
fn sin_cos(self) -> (Self, Self);
fn sin(self) -> Self;
fn cos(self) -> Self;
fn tan(self) -> Option<Self>;
}Expand description
Calculation of sine, cosine and tangent for number in degrees.
Required Methods
sourcefn sin_cos(self) -> (Self, Self)
fn sin_cos(self) -> (Self, Self)
Simultaneously calculate sinus and cosinus, returns (sin(self), cos(self)).
sourcefn sin(self) -> Self
fn sin(self) -> Self
Calculate sinus.
sin_cos should be used instead when both sinus and cosinus are needed.